==> anwiba-spatial-data-ckan-1.0.76-sources.jar: net/anwiba/spatial/ckan/json/schema/v1_0/ShapeInfo.java <==
//Copyright (c) 2017 by Andreas W. Bartels (bartels@anwiba.de)
package net.anwiba.spatial.ckan.json.schema.v1_0;

import com.fasterxml.jackson.annotation.JsonProperty;

public class ShapeInfo {

    private String error_class = "None";
    private Field[] layer_fields = null;
    private String layer_id = "None";
    private String error_type = "None";
    private String bounding_box = null;
    private String state = null;
    private DateString timestamp = null;
    private String message = null;

    @JsonProperty("error_class")
    public void setError_class(final String error_class) {
        this.error_class = error_class;
    }

    @JsonProperty("error_class")
    public String getError_class() {
        return this.error_class;
    }

    @JsonProperty("layer_fields")
    public void setLayer_fields(final Field[] layer_fields) {
        this.layer_fields = layer_fields;
    }

    @JsonProperty("layer_fields")
    public Field[] getLayer_fields() {
        return this.layer_fields;
    }

    @JsonProperty("layer_id")
    public void setLayer_id(final String layer_id) {
        this.layer_id = layer_id;
    }

    @JsonProperty("layer_id")
    public String getLayer_id() {
        return this.layer_id;
    }

    @JsonProperty("error_type")
    public void setError_type(final String error_type) {
        this.error_type = error_type;
    }

    @JsonProperty("error_type")
    public String getError_type() {
        return this.error_type;
    }

    @JsonProperty("bounding_box")
    public void setBounding_box(final String bounding_box) {
        this.bounding_box = bounding_box;
    }

    @JsonProperty("bounding_box")
    public String getBounding_box() {
        return this.bounding_box;
    }

    @JsonProperty("state")
    public void setState(final String state) {
        this.state = state;
    }

    @JsonProperty("state")
    public String getState() {
        return this.state;
    }

    @JsonProperty("timestamp")
    public void setTimestamp(final DateString timestamp) {
        this.timestamp = timestamp;
    }

    @JsonProperty("timestamp")
    public DateString getTimestamp() {
        return this.timestamp;
    }

    @JsonProperty("message")
    public void setMessage(final String message) {
        this.message = message;
    }

    @JsonProperty("message")
    public String getMessage() {
        return this.message;
    }

}

==> anwiba-spatial-data-ckan-1.1.121-sources.jar: net/anwiba/spatial/ckan/json/schema/v1_0/ShapeInfo.java <==
//Copyright (c) 2017 by Andreas W. Bartels
package net.anwiba.spatial.ckan.json.schema.v1_0;

import java.util.LinkedHashMap;
import java.util.Map;
import java.util.Objects;
import com.fasterxml.jackson.annotation.JsonAnyGetter;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonProperty;
import net.anwiba.spatial.ckan.json.types.DateString;

public class ShapeInfo {

    private String error_class = "None";
    private Field[] layer_fields = null;
    private String layer_id = "None";
    private String error_type = "None";
    private String bounding_box = null;
    private String state = null;
    private DateString timestamp = null;
    private String message = null;
    private final Map<java.lang.String, Object> _unknownMembers = new LinkedHashMap<java.lang.String, Object>();

    @JsonProperty("error_class")
    public void setError_class(final String error_class) {
        this.error_class = error_class;
    }

    @JsonProperty("error_class")
    public String getError_class() {
        return this.error_class;
    }

    @JsonProperty("layer_fields")
    public void setLayer_fields(final Field[] layer_fields) {
        this.layer_fields = layer_fields;
    }

    @JsonProperty("layer_fields")
    public Field[] getLayer_fields() {
        return this.layer_fields;
    }

    @JsonProperty("layer_id")
    public void setLayer_id(final String layer_id) {
        this.layer_id = layer_id;
    }

    @JsonProperty("layer_id")
    public String getLayer_id() {
        return this.layer_id;
    }

    @JsonProperty("error_type")
    public void setError_type(final String error_type) {
        this.error_type = error_type;
    }

    @JsonProperty("error_type")
    public String getError_type() {
        return this.error_type;
    }

    @JsonProperty("bounding_box")
    public void setBounding_box(final String bounding_box) {
        this.bounding_box = bounding_box;
    }

    @JsonProperty("bounding_box")
    public String getBounding_box() {
        return this.bounding_box;
    }

    @JsonProperty("state")
    public void setState(final String state) {
        this.state = state;
    }

    @JsonProperty("state")
    public String getState() {
        return this.state;
    }

    @JsonProperty("timestamp")
    public void setTimestamp(final DateString timestamp) {
        this.timestamp = timestamp;
    }

    @JsonProperty("timestamp")
    public DateString getTimestamp() {
        return this.timestamp;
    }

    @JsonProperty("message")
    public void setMessage(final String message) {
        this.message = message;
    }

    @JsonProperty("message")
    public String getMessage() {
        return this.message;
    }

    @JsonAnySetter
    public void set(final java.lang.String name, final Object value) {
        Objects.requireNonNull(name);
        this._unknownMembers.put(name, value);
    }

    @JsonAnyGetter
    public Map<java.lang.String, Object> get() {
        if (this._unknownMembers.isEmpty()) {
            return null;
        }
        return this._unknownMembers;
    }

}
